export default {
    "steps": {
      "page0": {
        "elements": [
          "h3",
          "h4",
          "injury_type"
        ],
        "buttons": {
          "previous": false
        }
      },
      "page1": {
        "elements": [
          "h2_1",
          "h4_1",
          "injury_time",
          "pain_level"
        ]
      },
      "page2": {
        "elements": [
          "h2",
          "h4_2",
          "chronic_conditions",
          "chronic_conditions_reason"
        ]
      },
      "page3": {
        "elements": [
          "h4_3",
          "serious_injuries",
          "serious_injuries_description"
        ]
      },
      "page4": {
        "elements": [
          "h2_2",
          "h4_4",
          "current_medications"
        ]
      },
      "page5": {
        "elements": [
          "h4_5",
          "swelling",
          "swelling_description"
        ]
      },
      "page6": {
        "elements": [
          "h2_3",
          "h4_6",
          "mobility_issues"
        ]
      },
      "page7": {
        "elements": [
          "h4_7",
          "rehabilitation_services",
          "rehabilitation_services_description"
        ]
      },
      "page8": {
        "elements": [
          "h2_4",
          "h4_8",
          "previous_peptide_therapies",
          "previous_peptide_therapies_description"
        ]
      },
      "page9": {
        "elements": [
          "h4_9",
          "peptide_sensitivities"
        ]
      },
      "page10": {
        "elements": [
          "h4_10",
          "pregnant"
        ]
      }
    },
    "schema": {
      "h3": {
        "type": "static",
        "tag": "h2",
        "content": "Injury Repair",
        "align": "left"
      },
      "h4": {
        "type": "static",
        "tag": "h4",
        "content": "What type of injury are you seeking treatment for?"
      },
      "injury_type": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "muscle strain",
            "label": "Muscle Strain"
          },
          {
            "value": "joint injury",
            "label": "Joint Injury"
          },
          {
            "value": "ligament tear",
            "label": "Ligament Tear"
          },
          {
            "value": "other",
            "label": "Other"
          }
        ]
      },
      "h2_1": {
        "type": "static",
        "tag": "h2",
        "content": "Injury Details"
      },
      "h4_1": {
        "type": "static",
        "tag": "h4",
        "content": "How long ago did the injury occur?"
      },
      "injury_time": {
        "type": "text",
        "inputType": "text",
        "rules": [
          "required"
        ]
      },
      "pain_level": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "1",
            "label": "1 (Mild)"
          },
          {
            "value": "2",
            "label": "2"
          },
          {
            "value": "3",
            "label": "3"
          },
          {
            "value": "4",
            "label": "4"
          },
          {
            "value": "5",
            "label": "5"
          },
          {
            "value": "6",
            "label": "6"
          },
          {
            "value": "7",
            "label": "7"
          },
          {
            "value": "8",
            "label": "8"
          },
          {
            "value": "9",
            "label": "9"
          },
          {
            "value": "10",
            "label": "10 (Severe)"
          }
        ]
      },
      "h2": {
        "type": "static",
        "tag": "h2",
        "content": "Medical History"
      },
      "h4_2": {
        "type": "static",
        "tag": "h4",
        "content": "Have you been diagnosed with any chronic medical conditions (e.g., diabetes, heart disease)?"
      },
      "chronic_conditions": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "chronic_conditions_reason": {
        "type": "text",
        "label": "If yes, please specify the condition.",
        "rules": [
          "required"
        ],
        "conditions": [
          [
            "chronic_conditions",
            "in",
            [
              "Yes"
            ]
          ]
        ]
      },
      "h4_3": {
        "type": "static",
        "tag": "h4",
        "content": "Do you have a history of any serious injuries or surgeries?"
      },
      "serious_injuries": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "serious_injuries_description": {
        "type": "text",
        "label": "If yes, please describe.",
        "rules": [
          "required"
        ],
        "conditions": [
          [
            "serious_injuries",
            "in",
            [
              "Yes"
            ]
          ]
        ]
      },
      "h2_2": {
        "type": "static",
        "tag": "h2",
        "content": "Current Medications"
      },
      "h4_4": {
        "type": "static",
        "tag": "h4",
        "content": "Are you currently taking any medications or supplements?"
      },
      "current_medications": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "h4_5": {
        "type": "static",
        "tag": "h4",
        "content": "Are you experiencing any swelling, bruising, or redness in the affected area?"
      },
      "swelling": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "swelling_description": {
        "type": "text",
        "label": "If yes, please describe.",
        "rules": [
          "required"
        ],
        "conditions": [
          [
            "swelling",
            "in",
            [
              "Yes"
            ]
          ]
        ]
      },
      "h2_3": {
        "type": "static",
        "tag": "h2",
        "content": "Mobility Issues"
      },
      "h4_6": {
        "type": "static",
        "tag": "h4",
        "content": "Are you having any issues with mobility or range of motion in the affected area?"
      },
      "mobility_issues": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "h4_7": {
        "type": "static",
        "tag": "h4",
        "content": "Have you undergone any physical therapy, chiropractic care, or other rehabilitation services for this injury?"
      },
      "rehabilitation_services": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "rehabilitation_services_description": {
        "type": "text",
        "label": "If yes, please describe.",
        "rules": [
          "required"
        ],
        "conditions": [
          [
            "rehabilitation_services",
            "in",
            [
              "Yes"
            ]
          ]
        ]
      },
      "h2_4": {
        "type": "static",
        "tag": "h2",
        "content": "Previous Treatments"
      },
      "h4_8": {
        "type": "static",
        "tag": "h4",
        "content": "Have you used any other peptide therapies or similar treatments in the past?"
      },
      "previous_peptide_therapies": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "previous_peptide_therapies_description": {
        "type": "text",
        "label": "If yes, please describe the results.",
        "rules": [
          "required"
        ],
        "conditions": [
          [
            "previous_peptide_therapies",
            "in",
            [
              "Yes"
            ]
          ]
        ]
      },
      "h4_9": {
        "type": "static",
        "tag": "h4",
        "content": "Do you have any known sensitivities to peptide-based therapies?"
      },
      "peptide_sensitivities": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      },
      "h4_10": {
        "type": "static",
        "tag": "h4",
        "content": "Are you Pregnant? (Female Specific)"
      },
      "pregnant": {
        "type": "radiogroup",
        "rules": [
          "required"
        ],
        "view": "blocks",
        "items": [
          {
            "value": "Yes",
            "label": "Yes"
          },
          {
            "value": "No",
            "label": "No"
          }
        ]
      }
    }
  }